==> catjs-0.4.67.tgz: package/README.md <==
CatJS 0.4.67
==============

<img align="right" width="201" height="94" src="https://raw.githubusercontent.com/catjsteam/catjs/master/resources/images/Logo48x48-01.png">

*CatJS* is an automation framework for (mobile) web applications testing.
It offers a new technology that makes testing easy, we don't do WebDriver like the other technologies, in our case the applications test themselves.
With simple annotations added to your HTML5 code, an automated functional tests will be available as part of your application lifecycle.

### Code once, deploy it anywhere <br/>

Once you added the test code you can run it using [CatJS runner](https://www.npmjs.org/package/mobilerunner) (That is already part of CatJS, no need to do any additional installations), on any platform that your application supports.
CatJS runner can deploy your application on multiple devices and desktop browsers.

### A few facts

* The annotations will be coded in comments thus no additional code is required
* Once you wish to test your application, with a simple command, a new deployment will be generated for you to use including the test code
* You get to document your tests and test your code
* When you are ready for production the additional annotations will be removed on the minify process.
* CatJS is an [NPM](https://www.npmjs.org/) and can be used as a command-line and/or as a module (The module will be available in the next releases)

[cat.js.team](http://catjsteam.github.io/) @catjsteam
You can visit our [catjs forum](https://groups.google.com/forum/#!forum/catjs). Comments and questions are more than welcome, our team can help and consult about how to test your web application.
  

## Blogs
[http://catjs.blogspot.co.il](]http://catjs.blogspot.co.il)

* Web Applications that test themselves
* Web automation testing solution

[Technology Through My Eyes](http://mobilewebtesting.wordpress.com/2014/06/22/how-to-test-your-mobile-web-application-using-catjs-part-one)

## Magazine

* [Method & tools article](http://www.methodsandtools.com/tools/catjs.php)

## CatJS - Seed project

We recommend you to try our catjs seed project on [jQuery Moblie app](http://jquerymobile.com/)  
Github project [https://github.com/ransnir/catjs-jqm-seed](https://github.com/ransnir/catjs-jqm-seed)  
Take a look on the [demo](http://ransnir.github.io/cat-project/target/catexample/index.html)

## Videos

### Getting started
[![ScreenShot](https://raw.githubusercontent.com/catjsteam/catjs/master/resources/images/catjsyoutube-s.png)](https://t.co/vBgLx9tEFF)  

### GTAC & Ignite Velocity events
[![ScreenShot](https://raw.githubusercontent.com/catjsteam/catjs/master/resources/images/gtac.jpg)](https://www.youtube.com/watch?v=gGdDc5SlBq4) [![ScreenShot](https://raw.githubusercontent.com/catjsteam/catjs/master/resources/images/velocity.jpg)](https://www.youtube.com/watch?v=nRcKAFS-Gyg)

## Release Notes Log

* **angularjs support* AngularJS support
* **Test Manager* Core test execution engine behavior fixes
* **Ready State** catjs internal tests execution ready state process added 
* **iframe support** Stabilized
* **iframe support** Initial IFrame feature added. It means that in case IFrame exists in the application, catjs library should be relatively imported at each IFrame. (see demo app: https://github.com/catjsteam/catjstests/tree/master/app/iframe)
* **auto-override** In the cat.json test project file this property enable/disable cat.json file override when using -a command-line flag
* **dependencies property** at the catproject.json format changed e.g. instead of ["jsutils", "jspath"] use [{"name": "jspath", "exclude": true}...]
* **external example** We have created another project for testing catjs core and put the best practices in the same place. The application that we are using is the TodoMVC implementations, currently we have started with [JQuery](https://github.com/catjsteam/catjstests/tree/master/app/todomvc/jquery) 
* **jquery plugin added** docs will be added in the next releases
* **third-party libraries** aggregation using the library name. catjs import should be modified using the new path cat/lib/cat/cat.js although the old path is supported  
* **Jasmin support** WIP 

## Documentation

* [Features](http://catjsteam.github.io/docs/core/catjs_features.html)
* [How It Works](http://catjsteam.github.io/docs/core/how_it_works.html)
* [Getting started](http://catjsteam.github.io/docs/core/getting_started.html)
* [Command Line Tool](http://catjsteam.github.io/docs/core/cli.html)
* [CatJS Project (Tool)](http://catjsteam.github.io/docs/core/catjs_tool.html)
* [Dependencies](http://catjsteam.github.io/docs/core/dependencies.html)
* [Test Project](http://catjsteam.github.io/docs/core/test_project.html)
* [Test Data](http://catjsteam.github.io/docs/core/test_data.html)
* [Annotations](http://catjsteam.github.io/docs/core/annotations.html)
* [Plugins](http://catjsteam.github.io/docs/core/plugins.html)
* [Reports](http://catjsteam.github.io/docs/core/reports.html)
* [Runner](http://catjsteam.github.io/docs/core/runner.html)
* [UI Console](http://catjsteam.github.io/docs/core/ui_console.html)
* [API](http://catjsteam.github.io/docs/core/api.html)
* [Troubleshooting & support](http://catjsteam.github.io/docs/core/troubleshooting.html)


<br/>
<div style="position: fixed; padding: 10px; top: 0; right:0; width:100%; text-align:right; cursor:pointer;" onclick="window.location.href='http://catjsteam.github.io/docs/user_guide.html'" > <span style="position: relative; right: 10px; top: 10px; padding-top:10px; font-size:10px; color:#444444">Applications That Test Themselves</span> <img align="right" width="50" height="24" src="https://raw.githubusercontent.com/catjsteam/catjs/master/resources/images/Logo48x48-01.png"></div><script> (function(){ for(var els = document.getElementsByTagName ('a'), i = els.length; i--;) { var elt = els[i]; elt.setAttribute("target","_blank"); if (elt.href.lastIndexOf(".md") !== -1) {elt.href = elt.href.split(".md").join(".html") } } })(); </script>

==> catjs-0.5.0.tgz: package/README.md <==
catjs 0.5.0 catjs.canary 0.5.0
==============

<img align="right" width="201" height="94" src="https://raw.githubusercontent.com/catjsteam/catjs/master/resources/images/Logo48x48-01.png">

*CatJS* is an automation framework for (mobile) web applications testing.
It offers a new technology that makes testing easy, we don't do WebDriver like the other technologies, in our case the applications test themselves.
With simple annotations added to your HTML5 code, an automated functional tests will be available as part of your application lifecycle.

### Code once, deploy it anywhere <br/>

Once you added the test code you can run it using [CatJS runner](https://www.npmjs.org/package/mobilerunner) (That is already part of CatJS, no need to do any additional installations), on any platform that your application supports.
CatJS runner can deploy your application on multiple devices and desktop browsers.

### A few facts

* The annotations will be coded in comments thus no additional code is required
* Once you wish to test your application, with a simple command, a new deployment will be generated for you to use including the test code
* You get to document your tests and test your code
* When you are ready for production the additional annotations will be removed on the minify process.
* CatJS is an [NPM](https://www.npmjs.org/) and can be used as a command-line and/or as a module (The module will be available in the next releases)

[cat.js.team](http://catjsteam.github.io/) @catjsteam
You can visit our [catjs forum](https://groups.google.com/forum/#!forum/catjs). Comments and questions are more than welcome, our team can help and consult about how to test your web application.
  

## Blogs
[http://catjs.blogspot.co.il](]http://catjs.blogspot.co.il)

* Web Applications that test themselves
* Web automation testing solution

[Technology Through My Eyes](http://mobilewebtesting.wordpress.com/2014/06/22/how-to-test-your-mobile-web-application-using-catjs-part-one)

## Magazine

* [Method & tools article](http://www.methodsandtools.com/tools/catjs.php)

## CatJS - Seed project

We recommend you to try our catjs seed project on [jQuery Moblie app](http://jquerymobile.com/)  
Github project [https://github.com/ransnir/catjs-jqm-seed](https://github.com/ransnir/catjs-jqm-seed)  
Take a look on the [demo](http://ransnir.github.io/cat-project/target/catexample/index.html)

## Videos

### Getting started
[![ScreenShot](https://raw.githubusercontent.com/catjsteam/catjs/master/resources/images/catjsyoutube-s.png)](https://t.co/vBgLx9tEFF)  

### GTAC & Ignite Velocity events
[![ScreenShot](https://raw.githubusercontent.com/catjsteam/catjs/master/resources/images/gtac.jpg)](https://www.youtube.com/watch?v=gGdDc5SlBq4) [![ScreenShot](https://raw.githubusercontent.com/catjsteam/catjs/master/resources/images/velocity.jpg)](https://www.youtube.com/watch?v=nRcKAFS-Gyg)

## Release Notes Log

* **snapshot for the browser** DOM snapshot annotation added that saves an image of a given **SVG**, **Canvas** or **DOM**(html2canvas) element. The images will be available in the reports folder.

        @[scrap
            @@name snapshots
            @@dom snapshot("#paper")
            @@dom snapshot("body")
            @@dom snapshot("#svgtest")
        ]@

        In case of DOM usage, add the html2canvas library
        Add the following to the catproject.json file:
        
        "dependencies": [
            {
                "name": "html2canvas",
                "exclude": false
            },
            {
                "name": "canvg",
                "exclude": false
            }
        ]

* **Wait to Object** Wait functionality is now supported, adding a standard wait, and\or wait to a DOM object and\or a functionality (TBD Documentation) see https://github.com/catjsteam/catjstests/tree/master/app/basic example application
* **Test Execution** catjs has a new tests execution engine with backward compatibility support and with additional new skills such as, waiting for other processes to complete before it continue to the next tasks. no more timing is required.   
* **NPM catjs.canary** <code>npm install -g catjs.canary</code> new NPM module for getting the latest repository changes [not fully tested] 
* **DOM plugin** Drag and Drop fixes 
* **testdb issue** test data json failed on parsing  
* **Scrap's name** can be used more than once in the catjs project (cat.json)  
* **DOM Plugin** Drag and Drop support (see https://github.com/catjsteam/catjstests) 
* **angularjs support** AngularJS with ng- actions supported 
* **iframe support** Stabilized
* **auto-override** In the cat.json test project file this property enable/disable cat.json file override when using -a command-line flag
* **dependencies property** at the catproject.json format changed e.g. instead of ["jsutils", "jspath"] use [{"name": "jspath", "exclude": true}...]

## Documentation

* [Features](http://catjsteam.github.io/docs/core/catjs_features.html)
* [How It Works](http://catjsteam.github.io/docs/core/how_it_works.html)
* [Getting started](http://catjsteam.github.io/docs/core/getting_started.html)
* [Command Line Tool](http://catjsteam.github.io/docs/core/cli.html)
* [CatJS Project (Tool)](http://catjsteam.github.io/docs/core/catjs_tool.html)
* [Dependencies](http://catjsteam.github.io/docs/core/dependencies.html)
* [Test Project](http://catjsteam.github.io/docs/core/test_project.html)
* [Test Data](http://catjsteam.github.io/docs/core/test_data.html)
* [Annotations](http://catjsteam.github.io/docs/core/annotations.html)
* [Plugins](http://catjsteam.github.io/docs/core/plugins.html)
* [Reports](http://catjsteam.github.io/docs/core/reports.html)
* [Runner](http://catjsteam.github.io/docs/core/runner.html)
* [UI Console](http://catjsteam.github.io/docs/core/ui_console.html)
* [API](http://catjsteam.github.io/docs/core/api.html)
* [Troubleshooting & support](http://catjsteam.github.io/docs/core/troubleshooting.html)


<br/>
<div style="position: fixed; padding: 10px; top: 0; right:0; width:100%; text-align:right; cursor:pointer;" onclick="window.location.href='http://catjsteam.github.io/docs/user_guide.html'" > <span style="position: relative; right: 10px; top: 10px; padding-top:10px; font-size:10px; color:#444444">Applications That Test Themselves</span> <img align="right" width="50" height="24" src="https://raw.githubusercontent.com/catjsteam/catjs/master/resources/images/Logo48x48-01.png"></div><script> (function(){ for(var els = document.getElementsByTagName ('a'), i = els.length; i--;) { var elt = els[i]; elt.setAttribute("target","_blank"); if (elt.href.lastIndexOf(".md") !== -1) {elt.href = elt.href.split(".md").join(".html") } } })(); </script>
